@@ -1,4 +1,4 @@
 import docgenerator
 
 def main():
-    truetool.run()
\ No newline at end of file
+    docgenerator.run()
\ No newline at end of file
